@@ -25,8 +25,11 @@ class TrainType(Enum):
 
 @unique
 class Internet(Enum):
-    UNKNOWN = None
-    UNSTABLE = 0
-    WEAK = 1
-    HIGH = 2
+    UNKNOWN = None  # Client can't tell
+    NO_INFO = -1  # Train can't tell
+    NO_INTERNET = 0
+    UNSTABLE = 1
+    WEAK = 2
+    MIDDLE = 3
+    HIGH = 4
 
